@@ -4,7 +4,7 @@ import multiprocessing
 import time
 from traceback import format_exc
 
-__version__ = '0.4'
+__version__ = '0.5'
 __author__ = 'Tikitu de Jager <tikitu@logophile.org>'
 
 
@@ -89,15 +89,18 @@ class PacketID(object):
 
 class Worker(Process):
 
-    def __init__(self, task_fn, worker_in_q, worker_out_q, max_packet_id_v, progress_event):
+    def __init__(self, task_fn, init_fn, worker_in_q, worker_out_q, max_packet_id_v, progress_event):
         super(Worker, self).__init__()
         self.task_fn = task_fn
         self.worker_in_q = worker_in_q
         self.worker_out_q = worker_out_q
         self.max_packet_id_v = max_packet_id_v
         self.progress_event = progress_event
+        self.init_fn = init_fn
 
     def run(self):
+        if self.init_fn:
+            self.init_fn()
         while True:
             packet_id, data = self.worker_in_q.get()
             try:
@@ -187,6 +190,7 @@ class ParallelSingleTaskQueue(object):
 
     def __init__(self, task_fn, num_workers=None, daemon=False,
                  in_q_max=1000, out_q_max=1000, worker_q_max=100,
+                 worker_init_f=None,
                  consumer_buffer_max=None,
                  progress_semaphore=None):
         """
@@ -218,7 +222,8 @@ class ParallelSingleTaskQueue(object):
         self._consumer.start()
 
         for _ in range(num_workers):
-            worker = Worker(task_fn, self.in_q, worker_out_q,
+            worker = Worker(task_fn, worker_init_f,
+                            self.in_q, worker_out_q,
                             max_packet_id_v, progress_event)
             worker.daemon = daemon
             worker.start()
